@@ -22,6 +22,10 @@ class Profiler:
 
 
 class TimerProfiler(Profiler):
+    """
+    A simple profiler using a timer
+    """
+
     def __init__(self, result_dir: Path):
         super().__init__(result_dir)
         self.start_time = 0
@@ -38,6 +42,10 @@ class TimerProfiler(Profiler):
 
 
 class ProfilerCollection:
+    """
+    A collection of profilers
+    """
+
     def __init__(self) -> None:
         self.profilers: dict[str, Profiler] = {}
 
