@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-from icsystemutils.network.remote import RemoteHost
+from icsystemutils.network import remote
 
 
 def create_file_with_text(path, content):
@@ -21,7 +21,7 @@ def test_remote_upload():
     return
 
     # TODO Add https://pypi.org/project/mock-ssh-server/
-    remote = RemoteHost("localhost")
+    host = remote.Host(name="localhost")
 
     file_name = "test_remote_upload"
     file_content = "test"
@@ -30,6 +30,6 @@ def test_remote_upload():
     create_file_with_text(local_path, file_content)
 
     remote_path = Path(os.getcwd()) / f"{file_name}_remote.dat"
-    remote.upload(local_path, remote_path)
+    remote.upload(host, local_path, remote_path, None)
 
     check_file_has_content(remote_path, file_content)
